import { renderless, api } from '@opentinyvue/vue-renderless/rate/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconStarActive, IconStarDisable, IconSmile, IconFrown, IconMeh } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "rate": "flex justify-start items-center text-center",
  "rate-item": "align-bottom flex-initial flex justify-center box-content [&>svg:nth-child(1)]:w-6 [&>svg:nth-child(1)]:h-6  px-2 sm:[&>svg:nth-child(1)]:w-4 sm:[&>svg:nth-child(1)]:h-4 sm:px-1",
  "rate-item-textOnBottom": "px-2 sm:px-1 inline-block",
  "cursor-disabled": "cursor-auto",
  "cursor-undisabled": "cursor-pointer",
  "svg-hover": "scale-[1.15]",
  "text-Bottom": "text-sm mt-2",
  "text-left": "text-color-text-primary text-sm  ml-6 leading-6 sm:ml-3 sm:leading-4",
  "allowhalf-item": "relative inline-block leading-none",
  "allowhalf-active": "inline-block  absolute top-0 left-1/2 -translate-x-1/2 w-6 h-6 sm:w-4 sm:h-4",
  "big-text-bottom": "text-base",
  "big-text-left": "text-color-text-primary sm:ml-5 sm:text-base sm:leading-6",
  "type-big": "sm:[&>svg:nth-child(1)]:w-6 sm:[&>svg:nth-child(1)]:h-6  sm:px-2"
};
var __vue2_script = defineComponent({
  emits: ["update:modelValue", "change"],
  props: [].concat(props, ["modelValue", "radio", "lowThreshold", "highThreshold", "max", "colors", "voidColor", "disabledVoidColor", "iconClasses", "voidIconClass", "disabledVoidIconClass", "disabled", "allowHalf", "showText", "showScore", "textColor", "texts", "textOnBottom", "type", "scoreTemplate"]),
  components: {
    IconStarActive: IconStarActive(),
    IconStarDisable: IconStarDisable(),
    IconSmile: IconSmile(),
    IconFrown: IconFrown(),
    IconMeh: IconMeh()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: _vm.m(_vm.gcls("rate")),
    attrs: {
      "data-tag": "tiny-rate",
      "tabindex": "0"
    },
    on: {
      "keydown": _vm.handelKey
    }
  }, [_vm._l(_vm.max, function(item) {
    return _c("span", {
      key: item,
      class: _vm.m(_vm.gcls({
        "allowhalf-item": _vm.allowHalf
      }), _vm.gcls("rate-item"), _vm.gcls(_vm.disabled ? "cursor-disabled" : "cursor-undisabled"), _vm.gcls({
        "rate-item-textOnBottom": _vm.textOnBottom
      }), _vm.gcls({
        "type-big": _vm.type === "large"
      })),
      attrs: {
        "data-tag": "tiny-rate-content"
      },
      on: {
        "mousemove": function mousemove($event) {
          return _vm.setCurrentValue({
            item,
            event: $event
          });
        },
        "mouseleave": _vm.resetCurrentValue,
        "click": function click($event) {
          return _vm.selectValue(item);
        }
      }
    }, [_c(_vm.state.classes[item - 1], {
      tag: "component",
      class: _vm.m(_vm.gcls({
        "svg-hover": _vm.state.hoverIndex === item
      })),
      style: _vm.getIconStyle(item)
    }), _vm.showDecimalIcon(item) ? _c(_vm.state.decimalIconClass, {
      tag: "component",
      class: _vm.m(_vm.gcls({
        "allowhalf-active": _vm.allowHalf
      })),
      style: _vm.state.decimalStyle
    }) : _vm._e(), _vm.textOnBottom && !_vm.radio ? _c("div", {
      class: _vm.m(_vm.gcls("text-Bottom"), _vm.gcls({
        "big-text-bottom": _vm.type === "large"
      })),
      style: {
        color: _vm.textColor
      },
      attrs: {
        "data-tag": "tiny-rate-text-bottom"
      }
    }, [_vm._v(" " + _vm._s(_vm.texts[item - 1]) + " ")]) : _vm._e(), _vm.textOnBottom && _vm.radio ? _c("div", {
      class: _vm.m(_vm.gcls("text-Bottom"), _vm.gcls({
        "big-text-bottom": _vm.type === "large"
      })),
      style: _vm.getTextStyle(),
      attrs: {
        "data-tag": "tiny-rate-radio-bottom"
      }
    }, [_vm._v(" " + _vm._s(_vm.texts[item - 1]) + " ")]) : _vm._e()], 1);
  }), !_vm.textOnBottom && _vm.showText || _vm.showScore ? _c("span", {
    class: _vm.m(_vm.gcls("text-left"), _vm.gcls({
      "big-text-left": _vm.type === "large"
    })),
    style: {
      color: _vm.textColor
    },
    attrs: {
      "data-tag": "tiny-rate-score"
    }
  }, [_vm._v(_vm._s(_vm.state.text))]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
